## $Id: pages.py 11840 2014-10-14 10:28:24Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from waeup.kofa.browser.pages import (
    SessionConfigurationAddFormPage, SessionConfigurationManageFormPage,
    LoginPage, CertificatePage, CertificateManageFormPage, DepartmentPage,
    DepartmentManageFormPage, CertificateAddFormPage, DepartmentAddFormPage,
    FacultyManageFormPage, FacultyAddFormPage)
from waeup.kofa.university.interfaces import ICertificate
from kofacustom.pcn.interfaces import (
    ICustomSessionConfiguration, ICustomSessionConfigurationAdd)

from kofacustom.pcn.university.faculty import IDepartment, IFaculty

grok.templatedir('templates')

class CustomSessionConfigurationAddFormPage(SessionConfigurationAddFormPage):
    """Add a session configuration object to configuration container.
    """
    form_fields = grok.AutoFields(ICustomSessionConfigurationAdd)

class CustomSessionConfigurationManageFormPage(SessionConfigurationManageFormPage):
    """Manage session configuration object.
    """
    form_fields = grok.AutoFields(ICustomSessionConfiguration)


class FacultyAddFormPage(FacultyAddFormPage):
    """ Page form to add a new faculty to a faculty container.
    """
    form_fields = grok.AutoFields(IFaculty)

class FacultyManageFormPage(FacultyManageFormPage):
    """Manage the basic properties of a `Faculty` instance.
    """
    form_fields = grok.AutoFields(IFaculty).omit('code')

class DepartmentPage(DepartmentPage):
    """Department index page.
    """

class DepartmentManageFormPage(DepartmentManageFormPage):
    """Department index page.
    """
    grok.template('departmentmanagepage')
    form_fields = grok.AutoFields(IDepartment).omit(
        'code', 'score_editing_disabled')

class DepartmentAddFormPage(DepartmentAddFormPage):
    """Department index page.
    """
    form_fields = grok.AutoFields(IDepartment).omit('score_editing_disabled')

class CertificatePage(CertificatePage):
    """Index page for certificates.
    """
    grok.template('certificatepage')

    form_fields = grok.AutoFields(ICertificate).omit(
        'study_mode', 'start_level', 'end_level', 'school_fee_2',
        'school_fee_3', 'school_fee_4', 'ratio')

class CertificateManageFormPage(CertificateManageFormPage):
    """Manage the properties of a `Certificate` instance.
    """
    grok.template('certificatemanagepage')

    form_fields = grok.AutoFields(ICertificate).omit(
        'code', 'study_mode', 'start_level', 'end_level', 'school_fee_2',
        'school_fee_3', 'school_fee_4', 'ratio')

class CertificateAddFormPage(CertificateAddFormPage):
    """Add-form to add certificate to a department.
    """
    form_fields = grok.AutoFields(ICertificate).omit(
        'study_mode', 'start_level', 'end_level', 'school_fee_2',
        'school_fee_3', 'school_fee_4', 'ratio')